summaryrefslogtreecommitdiffstats
path: root/karbon/widgets/vcanvas.h
diff options
context:
space:
mode:
Diffstat (limited to 'karbon/widgets/vcanvas.h')
-rw-r--r--karbon/widgets/vcanvas.h33
1 files changed, 17 insertions, 16 deletions
diff --git a/karbon/widgets/vcanvas.h b/karbon/widgets/vcanvas.h
index d0446087..09dc07d3 100644
--- a/karbon/widgets/vcanvas.h
+++ b/karbon/widgets/vcanvas.h
@@ -21,7 +21,7 @@
#define __VCANVAS_H__
-#include <qscrollview.h>
+#include <tqscrollview.h>
#include <koffice_export.h>
class KarbonPart;
class KarbonView;
@@ -29,19 +29,20 @@ class KoRect;
class KoPoint;
class VPainter;
-// The canvas is a QScrollView.
+// The canvas is a TQScrollView.
-class KARBONCOMMON_EXPORT VCanvas : public QScrollView
+class KARBONCOMMON_EXPORT VCanvas : public TQScrollView
{
Q_OBJECT
+ TQ_OBJECT
public:
- VCanvas( QWidget *parent, KarbonView* view, KarbonPart* part );
+ VCanvas( TQWidget *tqparent, KarbonView* view, KarbonPart* part );
virtual ~VCanvas();
- void repaintAll( const KoRect & );
- void repaintAll( bool drawVObjects = true );
+ void tqrepaintAll( const KoRect & );
+ void tqrepaintAll( bool drawVObjects = true );
- QPixmap *pixmap() { return m_pixmap; }
+ TQPixmap *pixmap() { return m_pixmap; }
/**
* Sets mouse position to point p.
@@ -72,17 +73,17 @@ public:
KoPoint snapToGrid( const KoPoint & );
protected:
- virtual void dragEnterEvent( QDragEnterEvent * );
- virtual void dropEvent( QDropEvent * );
- virtual void focusInEvent( QFocusEvent * );
- virtual void viewportPaintEvent( QPaintEvent* );
- virtual void drawContents( QPainter* painter, int clipx, int clipy,
+ virtual void dragEnterEvent( TQDragEnterEvent * );
+ virtual void dropEvent( TQDropEvent * );
+ virtual void focusInEvent( TQFocusEvent * );
+ virtual void viewportPaintEvent( TQPaintEvent* );
+ virtual void drawContents( TQPainter* painter, int clipx, int clipy,
int clipw, int cliph );
- void drawDocument( QPainter* painter, const KoRect& rect, bool drawVObjects = true );
+ void drawDocument( TQPainter* painter, const KoRect& rect, bool drawVObjects = true );
- virtual void resizeEvent( QResizeEvent* event );
+ virtual void resizeEvent( TQResizeEvent* event );
- virtual bool eventFilter( QObject* object, QEvent* event );
+ virtual bool eventFilter( TQObject* object, TQEvent* event );
void setYMirroring( VPainter * );
@@ -93,7 +94,7 @@ signals:
void viewportChanged();
private:
- QPixmap *m_pixmap;
+ TQPixmap *m_pixmap;
KarbonPart* m_part;
KarbonView* m_view;
};